<?php

namespace App\Services\ThirdPlatform;

use App\Repositories\Contracts\ThirdApiPlatformRepository;
use App\Support\Traits\Helpers;
use Illuminate\Support\Str;

class ThirdPlatformService extends PlatformAbstractService
{
    use Helpers;

    public function __construct()
    {
        parent::__construct(app(ThirdApiPlatformRepository::class));
    }

    public function checkPlatformToken($platformName)
    {
        $this->setPlatformName($platformName);
        $platform = $this->getPlatformInfo('platform_token');
        return $platform ? $platform : [];
    }

    public function checkUrlFrom($ip)
    {
        $platformInfo = $this->getPlatformInfo();
        if(!$platformInfo){
            return false;
        }
        if($platformInfo['platform_type'] == 'self'){
            $params = json_decode($platformInfo['platform_params'],true);
            if(!empty($params) && $params['whiteList']){
                if(!empty($params['whiteList'])){
                    foreach($params['whiteList'] as $whiteIp){
                        if(Str::contains($whiteIp, $ip)){
                            return true;
                        }
                    }
                }
            }
        }
        return false;
    }

    public function createPlatformToken($platformName)
    {
        $this->setPlatformName($platformName);
        $token = $this->getPlatformInfo('platform_token');
        if($token){
            $jwtToken = $this->generateToken($token);
            return $jwtToken;
        }
        return null;
    }
}

